@@ -11,10 +11,10 @@ LE_DEVS_SCAN_RESULT_CACHE = PKG_ROOT/'res'/'le_devs_scan_result.cache'
 
 from xpycommon.log import INFO, DEBUG
 
-from .. import LOG_LEVEL as BLUING_LOG_LEVEL
+from .. import LOG_LEVEL as PARENT_LOG_LEVEL
 
 
-LOG_LEVEL = BLUING_LOG_LEVEL
+LOG_LEVEL = PARENT_LOG_LEVEL
 # LOG_LEVEL = DEBUG
 
 
