@@ -6,10 +6,10 @@ PKG_NAME = 'install'
 
 from xpycommon.log import INFO, DEBUG
 
-from .. import LOG_LEVEL as BLUING_PLUGIN_LOG_LEVEL
+from .. import LOG_LEVEL as PARENT_LOG_LEVEL
 
 
-LOG_LEVEL = BLUING_PLUGIN_LOG_LEVEL
+LOG_LEVEL = PARENT_LOG_LEVEL
 
 
 from .__main__ import main
