@@ -42,7 +42,7 @@ def parse_cmdline(argv: list[str] = sys.argv[1:]) -> dict:
             print(__doc__)
             sys.exit()
     except Exception as e:
-        logger.error("{}: {}".format(e.__class__.__name__, e))
+        logger.error("{}: \"{}\"".format(e.__class__.__name__, e))
         sys.exit(1)
     else:
         return args
